pub struct EspAsyncTls<S>(/* private fields */)
where
S: PollableSocket;Implementations
Sourceimpl<S> EspAsyncTls<S>where
S: PollableSocket,
impl<S> EspAsyncTls<S>where
S: PollableSocket,
Sourcepub fn adopt(socket: S) -> Result<Self, EspError>
pub fn adopt(socket: S) -> Result<Self, EspError>
Create a new AsyncEspTls instance adopting the supplied socket.
The socket should be in a connected state.
Errors
ESP_ERR_NO_MEMif not enough memory to create the TLS connection
Sourcepub async fn negotiate(
&mut self,
hostname: &str,
cfg: &Config<'_>,
) -> Result<CompletedHandshake, EspError>
pub async fn negotiate( &mut self, hostname: &str, cfg: &Config<'_>, ) -> Result<CompletedHandshake, EspError>
Establish a TLS/SSL connection using the adopted socket.
Errors
ESP_ERR_INVALID_SIZEifcfg.alpn_protosexceeds 9 elements or avg 10 bytes/ALPNESP_FAILif connection could not be established
Sourcepub async fn negotiate_server(
&mut self,
cfg: &ServerConfig<'_>,
) -> Result<(), EspError>
pub async fn negotiate_server( &mut self, cfg: &ServerConfig<'_>, ) -> Result<(), EspError>
Establish a TLS/SSL connection using the adopted socket, acting as the server.
Requires ESP-IDF >= 5.5.0 with mbedTLS.
Note that the handshake is not bounded in time (cfg.tls_handshake_timeout_ms
is only honored by the blocking EspTls::negotiate_server), so a
misbehaving peer can keep the negotiation going indefinitely.
Callers which cannot afford that should race this future against a timer.
Errors
ESP_FAILif the connection could not be established
Sourcepub async fn read(&self, buf: &mut [u8]) -> Result<usize, EspError>
pub async fn read(&self, buf: &mut [u8]) -> Result<usize, EspError>
Read in the supplied buffer. Returns the number of bytes read.
pub fn poll_read( &self, ctx: &mut Context<'_>, buf: &mut [u8], ) -> Poll<Result<usize, EspError>>
Sourcepub async fn write(&self, buf: &[u8]) -> Result<usize, EspError>
pub async fn write(&self, buf: &[u8]) -> Result<usize, EspError>
Write the supplied buffer. Returns the number of bytes written.
pub fn poll_write( &self, ctx: &mut Context<'_>, buf: &[u8], ) -> Poll<Result<usize, EspError>>
pub async fn write_all(&self, buf: &[u8]) -> Result<(), EspError>
pub fn context_handle(&self) -> *mut esp_tls